==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonMilitaryToPerson.md <==
# PersonMilitaryToPerson


```text
fontawesome-6/Solid/PersonMilitaryToPerson
```

```text
include('fontawesome-6/Solid/PersonMilitaryToPerson')
```



| Illustration | PersonMilitaryToPerson |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonMilitaryToPerson.png) | ![illustration for PersonMilitaryToPerson](../../fontawesome-6/Solid/PersonMilitaryToPerson.Local.png) |




## PersonMilitaryToPerson

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonMilitaryToPerson
include('fontawesome-6/Solid/PersonMilitaryToPerson')

' renders the element
PersonMilitaryToPerson('PersonMilitaryToPerson', 'Person Military To Person', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonMilitaryToPerson
include('fontawesome-6/Solid/PersonMilitaryToPerson')

' renders the element
PersonMilitaryToPerson('PersonMilitaryToPerson', 'Person Military To Person', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/PersonMilitaryToPerson.md <==
# PersonMilitaryToPerson


```text
fontawesome-6/Solid/PersonMilitaryToPerson
```

```text
include('fontawesome-6/Solid/PersonMilitaryToPerson')
```



| Illustration | PersonMilitaryToPerson |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PersonMilitaryToPerson.png) | ![illustration for PersonMilitaryToPerson](../../fontawesome-6/Solid/PersonMilitaryToPerson.Local.png) |




## PersonMilitaryToPerson

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonMilitaryToPerson
include('fontawesome-6/Solid/PersonMilitaryToPerson')

' renders the element
PersonMilitaryToPerson('PersonMilitaryToPerson', 'Person Military To Person', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PersonMilitaryToPerson
include('fontawesome-6/Solid/PersonMilitaryToPerson')

' renders the element
PersonMilitaryToPerson('PersonMilitaryToPerson', 'Person Military To Person', 'an optional tech label', 'an optional description')
@enduml
```
